MYSHELL='which bash'
#!${MYSHELL}

########################## SMALL FUNCTIONS ##############################################

# A function that waits for the enter key to be pressed
wait_for_enter()
{
while true; do
        echo "Press [ENTER] to return to main menu."
        read temp
        if [ "$temp" = "" ]; then
                break
        else
                continue
        fi
done
}

# A function to check if overburn is enabled
check_overburn()
{
if [ "${OVERBURN}" = "yes" ]; then	# Is overburn enabled?
	OBURN="-overburn"		# yes it was
else
	echo "Not enabling overburn..."	# No it wasn't
	OBURN=""			
fi
}

# A function to see if files in temp dir should be deleted after burning is done
check_tempdel()
{
if [ "${DELTEMPBURN}" = "yes" ]; then
	rm -rf "${BURNDIR}"/*
	echo "Temporary files in ${BURNDIR} deleted..."
	wait_for_enter
else
	echo "Temporary files in ${BURNDIR} not deleted..."
	wait_for_enter
fi
}

# A function to see if audio files should be copy protected or not
# NOTE: The files will not be copy protected, but cdrecord will write
# into TOC that files are permitted to be copied or not.
check_copy()
{
if [ "${COPY_PROTECT}" = "yes" ]; then
	COPYING="-nocopy"
else
	COPYING="-copy"
fi
}

################################ AUDIO ###################################################

# a function to burn audio cds.
# it looks for wav-files in the BURNDIR (/tmp/burn/)..

audio_burning()
{
while read wav; do
	echo
	echo "$wav found"
	echo
	existing="yes"

done < <(find ${BURNDIR} -iname "*wav" | sort)

if [ "$existing" != "yes" ]; then
	echo
	echo "No audiofiles in ${BURNDIR}"
else
	if [ "${NORMALIZE}" = "yes" ]; then
		cd ${BURNDIR}
		normalize -m *.wav
	else
		echo "Not using Normalize..."
	fi

	check_overburn		# Overburn enabled?
	check_copy		# Copy protected?

	if cdrecord dev=${CDWRITER} speed=${SPEED} ${OPT_ONE:+"driveropts=$OPT_ONE"} \
	 -audio -pad -eject -v ${OBURN} ${COPYING} ${BURNDIR}/*.wav; then		#Burn audio cd
		echo
		echo "Burning complete."
		check_tempdel		# See if files in temp dir should be deleted
	else
		echo "Burning failed. Check docs for info." 1>&2
		wait_for_enter
	fi
fi
}

################################# ISO #############################################################

# to burn a .iso-file in the BURNDIR.
iso_burning()
{
while read iso; do
	echo
	echo "$iso found"					
	echo
	existing="yes"

done < <(find ${BURNDIR} -iname "*iso" | sort)

if [ "$existing" != "yes" ]; then
	echo
	echo "No ISO found in ${BURNDIR}"
	wait_for_enter
else
	check_overburn		# Check if overburn was enabled in configure
	if cdrecord dev=${CDWRITER} speed=${SPEED} ${OPT_ONE:+"driveropts=$OPT_ONE"} \
	 -eject -v ${OBURN} ${BURNDIR}/*.iso; then
		echo
		echo "Burning complete."
		check_tempdel
	else
		echo "Burning failed. Check docs for info." 1>&2
		wait_for_enter
	fi
fi
}

################################### DATA ##########################################################

# This is a function to burn all files in /tmp/burn/ as a data-CD.
# if there is an .iso-file in the BURNDIR already, it 'll execute iso_burning 
# to burn it; if there isn't one, then it'll create an iso and then execute the other function.

data_burning()
{
if [ "$(find ${BURNDIR} -iname '*iso' | sort)" != "" ]; then
	iso_burning
else
	echo; echo "Trying to create ISO-file"			#No ISO-file found, creating one.
	if eval "mkisofs -r -T -f -v -J -hide-joliet-trans-tbl -copyright \"${COPYRIGHT}\" \
		 -A \"${DESCRIPTION}\" -p \"${AUTHOR}\" -P \"${PUBLISHER}\" \
		 -volset \"${NAMEOFPACKAGE}\" -volset-size \"${NUMBEROFCDS}\" \
		 -volset-seqno \"${CURRENTNUMBER}\" -V \"${LABEL}\" \
		 -o ${BURNDIR}/BashBurn.iso ${BURNDIR}"; then
		iso_burning					# call function - declared above
	else
		echo "Error: Couldn't create an iso-file." 1>&2
		echo "Maybe you need write permission?" 1>&2
		wait_for_enter
	fi
fi
}

################################## PIPELINE ########################################################

#A function to do direct audio burning without creating wavs.
pipeline_burning()
{
#fifo counter set to 0
COUNTER=0;
FIFOLST="";
COMMANDLST="";
while read FILE; do
	#AAARG...suffixe determination is too ugly !
        if [ "$( echo ${FILE} | sed -e 's/.*\.\(...\)$/\1/' | tr '[:lower:]' '[:upper:]'  )"x = "MP3x" ]; then
		COUNTER=$[ ${COUNTER} + 1 ];
		FIFO="${FIFODIR}/FIFO$$-${COUNTER}";
		FIFOLST="${FIFOLST} ${FIFO}";
		COMMANDLST="${COMMANDLST} -audio ${FIFO}";
		mknod ${FIFO} p; #equivalent to mkfifo $FIFO
		
		#Why not to choose between L3dec and mpg123 ?
		#Oh, it's pretty simple, nobody uses the first.
		# l3dec "$FILE" "$FIFO" -sa -ign 2>/dev/null &

		exec mpg123 -qs "${FILE}" 1> "${FIFO}" &
		echo ${COUNTER-MP3} $( echo $(basename "${FILE}") | head -c35 )  flushed into ${FIFO} \(pipe\).
	elif [ "$( echo ${FILE} | sed -e 's/.*\.\(...\)$/\1/' | tr '[:lower:]' '[:upper:]'  )"x = "WAVx" ]; then
		COUNTER=$[ ${COUNTER} + 1 ];
		IFOF="${FIFODIR}/FILE$$-${COUNTER}.wav";
		FIFOLST="${FIFOLST} ${IFOF}";
		ln -s "${FILE}" ${IFOF}
		COMMANDLST="${COMMANDLST} -audio ${IFOF}";
		echo ${COUNTER-WAV} $( echo $(basename "${FILE}") | head -c35 ).
	fi
done < <(find ${BURNDIR} -iname \*mp3 -o -iname \*wav | sort)

if [ "${COUNTER}" = "0" ]; then
	echo "No WAV of MP3 files in ${BURNDIR}" 1>&2
	echo "Sorry my lord" 1>&2
	wait_for_enter
fi

echo "Going to burn ${COUNTER} TRACKS !!!"
check_copy		#Check copy protection
cdrecord dev=${CDWRITER} speed=${SPEED} ${OPT_DRIVER:+"driver=$OPT_DRIVER"} \
 fs=16m -swab -audio -pad -eject -v ${OBURN} ${COPYING} ${COMMANDLST}
echo "Clean unused fifos"
rm ${FIFOLST}
check_tempdel
}

# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
case "$1" in
	"--audio")
		audio_burning
	;;
	"--data")
		data_burning
	;;
	"--iso")
		iso_burning
	;;
	"--pipeline")
		pipeline_burning
	;;
esac
